@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -26,14 +26,13 @@ extern "C" {
   Define declarations.
 */
 #define MagickPackageName "ImageMagick"
-#define MagickCopyright  "Copyright (C) 1999-2015 ImageMagick Studio LLC"
-#define MagickSVNRevision  "18623"
-#define MagickLibVersion  0x691
-#define MagickLibVersionText  "6.9.1"
-#define MagickLibVersionNumber  2,0,0
-#define MagickLibAddendum  "-3"
-#define MagickLibInterface  2
-#define MagickLibMinInterface  2
+#define MagickCopyright  "© 1999-2018 ImageMagick Studio LLC"
+#define MagickLibVersion  0x69A
+#define MagickLibVersionText  "6.9.10"
+#define MagickLibVersionNumber  6,0,0
+#define MagickLibAddendum  "-11"
+#define MagickLibInterface  6
+#define MagickLibMinInterface  6
 #if defined(_WINDOWS)
 #  if defined(_WIN64)
 #    define MagickPlatform "x64"
@@ -41,21 +40,18 @@ extern "C" {
 #    define MagickPlatform "x86"
 #  endif
 #else
-#define MagickPlatform  "x86_64"
+#define MagickPlatform  "i686"
 #endif
-#define MagickppLibVersionText  "6.9.1"
-#define MagickppLibVersionNumber  6:0:0
-#define MagickppLibAddendum  "-3"
-#define MagickppLibInterface  6
-#define MagickppLibMinInterface  6
-#define MagickReleaseDate  "2015-07-01"
-#define MagickChangeDate   "20150524"
-#define MagickFeatures "DPC OpenMP"
-#define MagickDelegates "autotrace bzlib mpeg fftw fpx fontconfig freetype gslib jbig jng jpeg lcms lzma pango png ps rsvg tiff webp x xml zlib"
+#define MagickppLibVersionText  "6.9.10"
+#define MagickppLibVersionNumber  8:0:0
+#define MagickppLibAddendum  "-11"
+#define MagickppLibInterface  8
+#define MagickppLibMinInterface  8
+#define MagickReleaseDate  "2020-06-25"
 #define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6/index.html"
 #define MagickAuthoritativeLicense  \
-  "http://www.imagemagick.org/script/license.php"
-#define MagickAuthoritativeURL  "http://www.imagemagick.org"
+  "https://www.imagemagick.org/script/license.php"
+#define MagickAuthoritativeURL  "https://www.imagemagick.org"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
